import itertools
import uuid
from datetime import datetime,date
from django.db import models
from django.contrib.auth import get_user_model
from django.db.models.signals import post_save, pre_save
from django.dispatch import receiver
from django.utils.text import slugify
from django.core.mail import EmailMessage

from djangoldp.models import Model
from djangoldp_conversation.models import Conversation


User = get_user_model()



class organisationSupport(Model):
  """Allow citizens to sign a text that is in an action group"""
  created_at = models.DateTimeField(auto_now_add=True)
  name = models.CharField(max_length=100, verbose_name=u"Nom de l'organisme")
  website = models.CharField(max_length=100, verbose_name=u"Site internet", null=True, blank=True)
  logo = models.URLField(verbose_name=u"Image", null=True, blank=True)
  #supported_email = models.ForeignKey(TextSupporters_Email, related_name="supported_email", blank=True, null=True)
  class Meta:
    serializer_fields = ['@id','name','website','logo']
    nested_fields=[]
    anonymous_perms = ['view','add']
    authenticated_perms = ['inherit','view', 'add']
    ordering=['-created_at']

  def __str__(self):
      return self.name

class imageToShare(Model):
  title = models.URLField(verbose_name=u"Image", null=True, blank=True)

  class Meta:
    serializer_fields = ['@id','title']
    anonymous_perms = ['view']
    authenticated_perms = ['inherit', 'add']

  def __str__(self):
      return self.title

class Tag(Model):
  name = models.CharField(max_length=100, verbose_name=u"Tag name")
  class Meta:
    serializer_fields = ['@id','name']
  def __str__(self):
      return self.name

class conditionTag(Model):
  name = models.CharField(max_length=100, verbose_name=u"Tag name")
  class Meta:
    serializer_fields = ['@id','name']
  def __str__(self):
      return self.name

class reasonsToLegalize(Model):
  title = models.CharField(max_length=150, verbose_name=u"titre de l'argument")
  content = models.TextField(verbose_name=u"Description de l'argument")
  source = models.URLField(verbose_name=u"source", null=True, blank=True)
  tag = models.ManyToManyField(Tag,verbose_name=u"Type d'argument")

  class Meta:
    serializer_fields = ['@id','title','content','source','tag']
    anonymous_perms = ['view']
    authenticated_perms = ['inherit', 'add']
    ordering = ['?']

  def __str__(self):
    return self.title


class legalisationCondition(Model):
  title = models.CharField(max_length=150, verbose_name=u"titre")
  content = models.TextField(verbose_name=u"Description")
  source = models.URLField(verbose_name=u"source", null=True, blank=True)
  tag = models.ManyToManyField(conditionTag,verbose_name=u"Type")

  class Meta:
    serializer_fields = ['@id','title','content','source','tag']
    anonymous_perms = ['view']
    authenticated_perms = ['inherit', 'add']
    ordering = ['?']

  def __str__(self):
    return self.title