import {
  SIBTemplateElement,
  Helpers
} from "https://unpkg.com/@startinblox/core@0.9";

Helpers.importCSS('/static/css/risefor-map.css');

export default class RiseForMap extends SIBTemplateElement {
  constructor() {
    super();
    this.uniqID = this.parentNode.id;
  }
  static get propsDefinition() {
    return {
      dataSrc: "data-src",
      rangeThemes: "range-themes",
      detailRoute: "detail-route",
      createRoute: "create-route",
    };
  }

  template({ dataSrc, rangeThemes, detailRoute, createRoute }) {
    return `
      <sib-map
        data-src="${dataSrc}"
        search-fields="header, postcode, theme, create"

        search-label-header="Filtrer les actions"
        search-label-postcode="Par code postal"
        search-label-theme="Par thème"

        search-widget-header="sib-form-label"
        search-widget-postcode="sib-form-placeholder-text"
        search-widget-theme="sib-form-placeholder-dropdown"
        search-widget-create="rfm-display-create"

        search-range-theme="${rangeThemes}"

        next="action-preview-${this.uniqID}"
      ></sib-map>

      <div id="map-${this.uniqID}" hidden></div>
      <div id="action-preview-${this.uniqID}" hidden>
        <sib-display
          bind-resources

          fields="theme.photo, name, description, date-and-location(city), cta, close"

          widget-theme.photo="sib-display-img"

          label-cta="Je participe"
          label-close="🞩"

          action-cta="${detailRoute}"
          action-close="map-${this.uniqID}"
        ></sib-display>
      </div>

      <sib-widget name="sib-form-label">
        <template>
          <div>\$\{label\}</div>
        </template>
      </sib-widget>

      <sib-widget name="rfm-display-create">
        <template>
          <sib-ac-checker permission="acl:Append" data-src="${dataSrc}">
            <sib-link next="${createRoute}">Créer une action</sib-link>
          </sib-ac-checker>
        </template>
      </sib-widget>

      <sib-router default-route="map-${this.uniqID}">
        <sib-route name="map-${this.uniqID}" hidden></sib-route>
        <sib-route name="action-preview-${this.uniqID}" use-id hidden></sib-route>
      </sib-router>
    `;
  }
}
customElements.define("risefor-map", RiseForMap);
